# Changelog

## [3.1.1a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/3.1.1a1) (2024-11-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/3.1.0...3.1.1a1)

**Merged pull requests:**

- fix: update deprecated imports from ovos-utils [\#300](https://github.com/OpenVoiceOS/OVOS-workshop/pull/300) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
